function [Keqind,Peqmax]=ComputeEquilibrium(breakevenprice,Feed,mu,sigma,delta,r,mgrid,kgrid,xgrid,GRIDMIN,TOLE);

alfa=exp(sigma*sqrt(delta)); % multiplier to get next period value
q=(1/2)*(1+(mu-sigma^2/2)*sqrt(delta)/sigma); % probability of going up
disc=exp(-r*delta); % discount factor
Iflow=breakevenprice*8760; %investment cost in flow units (annual rental cost of capital; in continuous time, Iflow=rI)

% This vecor will contain the myopic entry thresholds for each value of k
xstar=zeros(size(kgrid));

mcurrent=2;
while AnnualRevenue(0,xgrid(mcurrent),Feed)<Iflow,
    mcurrent=mcurrent+1
end


valuepos=0; %indicator for finding a positive value for an incremental unit (which is the same as finding optimal entry threshold)

for kind=1:length(kgrid), % loop for computing lowest entry point at all capacity levels
    k=kgrid(kind);
    k
    if mcurrent<length(mgrid),
        valuepos=0;
    end
            
    while valuepos==0,
        gridlow=max(mcurrent-(GRIDMIN-1),1);  % This is to keep lowest grid point within "mgrid"
        mgridtemp=mgrid(gridlow:mcurrent);
        xgridtemp=xgrid(gridlow:mcurrent);
        
        valuegrid=zeros(size(mgridtemp));
        revgrid=valuegrid;
        
        for Rindex=1:length(valuegrid),
            revgrid(Rindex)=AnnualRevenue(k,xgridtemp(Rindex),Feed);
        end

        valuenew=FindValueFunction((revgrid-Iflow).*delta,disc,q,(revgrid(1)-Iflow)*delta*(1/(1-disc)),0,TOLE);

        
        if valuenew(end)<0, % not optimal to enter at the candidate threshold
            mcurrent=mcurrent+1
            if mcurrent>=length(mgrid),
                valuepos=1;
                xstar(kind:end)=1000000;
            end
        else
            valuepos=1; % optimal entry threshold has been found
            xstar(kind)=alfa^(mgrid(1)+(mcurrent-1)); % entry threshold for the current capacity level
        end
        
    end
end


% The following creates vectors to express equilibrium capacity path and
% equilibrium maximum price as functions of oil price
xplotgrid=xgrid;
while xplotgrid(end)>=xstar(end),
    xplotgrid=xplotgrid(1:end-1);
end
kplot=zeros(size(xplotgrid));
kind=zeros(size(xgrid));
revmax=zeros(size(xplotgrid));
pricemax=zeros(size(xgrid));
revmid=zeros(size(xplotgrid));
revlow=zeros(size(xplotgrid));
for xind=1:length(xplotgrid),
    if xstar(end)<xplotgrid(xind),
        kplot(xind)=kgrid(end);
        ktemp=length(kgrid);
    else
        ktemp=min(find(xstar>xplotgrid(xind)+0.0001))-1;
        ktemp=max(1,ktemp);
        kplot(xind)=kgrid(ktemp);
    end
    kind(xind)=ktemp;
    revmax(xind)=AnnualRevenue(kgrid(ktemp),xgrid(xind),Feed);
    pricemax(xind)=revmax(xind)/8760;
end

Keqind=kind; % Corresponding index in kgrid
Peqmax=pricemax; % Maximum consumer price in equilibrium (average annual price)